pub struct GameSave {Show 18 fields
pub version: NaiveDate,
pub ticks: i64,
pub cube_len: u32,
pub max_entity_id: u32,
pub group_len: u32,
pub group_headers: Vec<EntityHeader>,
pub cube_groups: Vec<BlockGroupEntity>,
pub cube_headers: Vec<EntityHeader>,
pub cube_entities: Vec<Box<dyn Block>>,
pub wire_len: u32,
pub wire_headers: Vec<EntityHeader>,
pub wire_entities: Vec<SerializedWireEntity>,
pub wire_settings_header: EntityHeader,
pub wire_settings_entity: SerializedGlobalWireSettingsEntity,
pub flycam_header: EntityHeader,
pub flycam_entity: SerializedFlyCamEntity,
pub phycam_header: EntityHeader,
pub phycam_entity: SerializedPhysicsCameraEntity,
}Expand description
A collection of cubes and other data from a GameSave.techblox file
Fields
version: NaiveDateGame version that this save was created by. This may affect how the rest of the save file was parsed.
ticks: i64Time when file was saved, corresponding to ticks since 0 AD https://docs.microsoft.com/en-us/dotnet/api/system.datetime.ticks?view=netframework-4.7.2 Not used for deserialization so not required to be sensible.
cube_len: u32Amount of cubes present in the save data, as claimed by the file header.
max_entity_id: u32Maximum block entity identifier in the game save. Not used for deserialization so not required to be correct.
group_len: u32Amount of block groups, as claimed by the file header.
group_headers: Vec<EntityHeader>Entity group descriptors for block group entities.
cube_groups: Vec<BlockGroupEntity>Block group entities.
cube_headers: Vec<EntityHeader>Entity group descriptors for block entities.
cube_entities: Vec<Box<dyn Block>>Blocks
wire_len: u32Amount of wires in the save data, as claimed by the file.
wire_headers: Vec<EntityHeader>Entity group descriptor for wire entities.
wire_entities: Vec<SerializedWireEntity>Wires
wire_settings_header: EntityHeaderEntity group descriptor for wire settings
wire_settings_entity: SerializedGlobalWireSettingsEntityWire settings
flycam_header: EntityHeaderEntity group descriptor for player fly camera
flycam_entity: SerializedFlyCamEntityPlayer edit mode fly camera
phycam_header: EntityHeaderEntity group descriptor for player simulation mode camera
phycam_entity: SerializedPhysicsCameraEntityPlayer simulation mode camera